### SYLO
### A Simple Pomodoro Timer For The Terminal

## Install

`pip install sylo`

## Run

`sylo`

## Configure

### Optional arguments

`-w` `--work_time` Overwrite the default time in minutes to work (default is 25 minutes)
`-b` `--break_time` Overwrite the default time in minutes for a break (default is 5 minutes)


## Acknowledgements

SYLO Relies on `simpleaudio <https://github.com/hamiltron/py-simple-audio>` for its sounds. Sound out to `beepy <https://github.com/prabeshdhakal/beepy-v1>`.
